@@ -745,14 +745,14 @@ def restart_web(doCollectStatic=None, nginxOnly=False):
 
 @task
 @parallel
-def reload_worker(async="djangorq", doCollectStatic=None):
+def reload_worker(asyncw="djangorq", doCollectStatic=None):
     swap_code()
     if doCollectStatic in TRUTH_VALUES:
         collect_static()
 
-    if async == "djangorq":
+    if asyncw == "djangorq":
         reload_djangorq()
-    elif async == "celery":
+    elif asyncw == "celery":
         restart_celery()
     else:
         logger.info("Specified async facility not supported")
@@ -760,14 +760,14 @@ def reload_worker(async="djangorq", doCollectStatic=None):
 
 @task
 @parallel
-def restart_worker(async="djangorq", doCollectStatic=None):
+def restart_worker(asyncw="djangorq", doCollectStatic=None):
     swap_code()
     if doCollectStatic in TRUTH_VALUES:
         collect_static()
 
-    if async == "djangorq":
+    if asyncw == "djangorq":
         restart_djangorq()
-    elif async == "celery":
+    elif asyncw == "celery":
         restart_celery()
     else:
         logger.info("Specified async facility not supported")
